@@ -63,7 +63,7 @@ Version contants
 .. data:: LRO_MIRRORLIST
 
     *String or None*. **DEPRECATED** Set mirrorlist url (url could point
-    to a metalink mirrorlist or to a simple mirrorlist where each line wihtout
+    to a metalink mirrorlist or to a simple mirrorlist where each line without
     ``'#'`` is considered as mirror url).
 
 .. data:: LRO_MIRRORLISTURL
@@ -77,7 +77,7 @@ Version contants
 .. data:: LRO_LOCAL
 
     *Boolean*. If set to True, no local copy of repository is created
-    and repository is just localised in its current location.
+    and repository is just localized in its current location.
     When True, url of repository MUST be a local address
     (e.g. '/home/user/repo' or 'file:///home/user/repo').
 
@@ -99,7 +99,7 @@ Version contants
 
 .. data:: LRO_PROXYPORT
 
-    *Integer or None*. Set proxy port number to connect unsless
+    *Integer or None*. Set proxy port number to connect unless
     it is specified in the proxy address string. None sets default
     value 1080.
 
@@ -152,7 +152,7 @@ Version contants
 
 .. data:: LRO_IGNOREMISSING
 
-    *Boolean*. If you want to localise (LRO_LOCAL is True) a incomplete local
+    *Boolean*. If you want to localize (LRO_LOCAL is True) a incomplete local
     repository (eg. only primary and filelists are present but repomd.xml
     contains more files), you could use LRO_YUMDLIST and specify only file
     that are present, or use LRO_YUMBLIST and specify files that are not
@@ -268,7 +268,7 @@ Version contants
 
 .. data:: LRO_YUMBLIST
 
-    *List of strings*. Set blacklist of yum metadata files.
+    *List of strings*. Set skiplist of yum metadata files.
     This files will not be downloaded.
 
 .. data:: LRO_RPMMDBLIST
@@ -291,6 +291,14 @@ Version contants
     of digital signatures, rooted in certification authority
     (CA) certificates.
 
+.. data:: LRO_SSLVERIFYSTATUS
+
+    *Boolean*.  This option determines whether librepo verifies the status
+    of the server cert using the 'Certificate Status Request' TLS extension
+    (aka. OCSP stapling).
+    Note that if this option is enabled but the server does not support
+    the TLS extension, the verification will fail. */
+
 .. data:: LRO_SSLVERIFYHOST
 
     *Boolean*. This option determines whether librepo verifies that
@@ -311,6 +319,33 @@ Version contants
     *String or None*. Path to a file containing the list of PEM format
     trusted CA certificates.
 
+.. data:: LRO_PROXY_SSLVERIFYPEER
+
+    *Boolean*. This option determines whether librepo verifies the
+    authenticity of the proxy certificate. This trust is based on a chain
+    of digital signatures, rooted in certification authority
+    (CA) certificates.
+
+.. data:: LRO_PROXY_SSLVERIFYHOST
+
+    *Boolean*. This option determines whether librepo verifies
+    the name of the proxy certificate against the host.
+
+.. data:: LRO_PROXY_SSLCLIENTCERT
+
+    *String or None*. Path to the PEM format SSL client certificate to use
+    when talking to the proxy.
+
+.. data:: LRO_PROXY_SSLCLIENTKEY
+
+    *String or None*. Path to the PEM format SSL client key to use when
+    talking to the proxy.
+
+.. data:: LRO_PROXY_SSLCACERT
+
+    *String or None*. Path to a file containing the list of PEM format
+    trusted CA certificates. Used for proxy.
+
 .. data:: LRO_IPRESOLVE
 
     *Integer or None* Sets kind of IP addresses to use when resolving host
@@ -417,10 +452,16 @@ Version contants
 .. data:: LRI_FASTESTMIRRORMAXAGE
 .. data:: LRI_HMFCB
 .. data:: LRI_SSLVERIFYPEER
+.. data:: LRI_SSLVERIFYSTATUS
 .. data:: LRI_SSLVERIFYHOST
 .. data:: LRI_SSLCLIENTCERT
 .. data:: LRI_SSLCLIENTKEY
 .. data:: LRI_SSLCACERT
+.. data:: LRI_PROXY_SSLVERIFYPEER
+.. data:: LRI_PROXY_SSLVERIFYHOST
+.. data:: LRI_PROXY_SSLCLIENTCERT
+.. data:: LRI_PROXY_SSLCLIENTKEY
+.. data:: LRI_PROXY_SSLCACERT
 .. data:: LRI_IPRESOLVE
 .. data:: LRI_ALLOWEDMIRRORFAILURES
 .. data:: LRI_ADAPTIVEMIRRORSORTING
@@ -1358,6 +1399,10 @@ class Handle(_librepo.Handle):
 
         See :data:`.LRO_SSLVERIFYPEER`
 
+    .. attribute:: sslverifystatus:
+
+        See :data:`.LRO_SSLVERIFYSTATUS`
+
     .. attribute:: sslverifyhost:
 
         See :data:`.LRO_SSLVERIFYHOST`
@@ -1374,6 +1419,26 @@ class Handle(_librepo.Handle):
 
         See :data:`.LRO_SSLCACERT`
 
+    .. attribute:: proxy_sslverifypeer:
+
+        See :data:`.LRO_PROXY_SSLVERIFYPEER`
+
+    .. attribute:: proxy_sslverifyhost:
+
+        See :data:`.LRO_PROXY_SSLVERIFYHOST`
+
+    .. attribute:: proxy_sslclientcert:
+
+        See :data:`.LRO_PROXY_SSLCLIENTCERT`
+
+    .. attribute:: proxy_sslclientkey:
+
+        See :data:`.LRO_PROXY_SSLCLIENTKEY`
+
+    .. attribute:: proxy_sslcacert:
+
+        See :data:`.LRO_PROXY_SSLCACERT`
+
     .. attribute:: ipresolve:
 
         See :data:`.LRO_IPRESOLVE`
@@ -1662,7 +1727,7 @@ def set_debug_log_handler(log_function, user_data=None):
     Example::
 
         def debug_function(msg, _):
-            print msg
+            print(msg)
         librepo.set_debug_log_handler(debug_function)
 
     """
