@@ -158,7 +158,7 @@ lr_gettmpfile(void)
     template = g_build_filename(g_get_tmp_dir(), "librepo-tmp-XXXXXX", NULL);
     fd = mkstemp(template);
     if (fd < 0) {
-        perror("Cannot create temporary file - mkstemp");
+        fprintf(stderr, "Cannot create temporary file - mkstemp '%s': %s\n", template, strerror(errno));
         exit(1);
     }
     unlink(template);
@@ -170,7 +170,7 @@ lr_gettmpdir(void)
 {
     char *template = g_build_filename(g_get_tmp_dir(), "librepo-tmpdir-XXXXXX", NULL);
     if (!mkdtemp(template)) {
-        lr_free(template);
+        g_free(template);
         return NULL;
     }
     return template;
@@ -206,7 +206,7 @@ lr_pathconcat(const char *first, ...)
 
     qmark_section = strchr(first, '?');
 
-    res = lr_malloc(total_len + separator_len + 1);
+    res = g_malloc(total_len + separator_len + 1);
 
     next = first;
     va_start(args, first);
@@ -255,12 +255,12 @@ lr_pathconcat(const char *first, ...)
 
         /* Prepend separator - except first element */
         if (is_first == 0) {
-            strncpy(res + offset, separator, separator_len);
+            memcpy(res + offset, separator, separator_len);
             offset += separator_len;
         } else
             is_first = 0;
 
-        strncpy(res + offset, start, end - start);
+        memcpy(res + offset, start, end - start);
         offset += end - start;
     }
     va_end(args);
@@ -273,13 +273,13 @@ lr_pathconcat(const char *first, ...)
     assert(offset <= total_len);
 
     if (offset == 0) {
-        lr_free(res);
+        g_free(res);
         return g_strdup(first);
     }
 
     /* If last element was emtpy string, append separator to the end */
     if (previous_was_empty && is_first == 0) {
-        strncpy(res + offset, separator, separator_len);
+        memcpy(res + offset, separator, separator_len);
         offset += separator_len;
     }
 
