@@ -9,11 +9,10 @@ import xattr
 
 import tests.servermock.yum_mock.config as config
 
-from tests.base import TestCaseWithFlask
-from tests.servermock.server import app
+from tests.base import TestCaseWithServer
 
 
-class TestCaseYumPackageDownloading(TestCaseWithFlask):
+class TestCaseYumPackageDownloading(TestCaseWithServer):
 
     def setUp(self):
         self.tmpdir = tempfile.mkdtemp(prefix="librepotest-", dir="./")
@@ -163,9 +162,7 @@ class TestCaseYumPackageDownloading(TestCaseWithFlask):
         pkg = os.path.join(self.tmpdir, config.PACKAGE_01_01)
         self.assertTrue(os.path.isfile(pkg))
 
-class TestCaseYumPackagesDownloading(TestCaseWithFlask):
-    application = app
-
+class TestCaseYumPackagesDownloading(TestCaseWithServer):
 #    @classmethod
 #    def setUpClass(cls):
 #        super(TestCaseYumPackageDownloading, cls).setUpClass()
@@ -679,7 +676,7 @@ class TestCaseYumPackagesDownloading(TestCaseWithFlask):
         # the mirror list should be 1, 3, 4. The metalink file
         # defines preference order. This is the order in which
         # the URLs are listed in the file
-        self.assertEquals(h.mirrors, [url1, url2, url3])
+        self.assertEqual(h.mirrors, [url1, url2, url3])
 
         # YUM 01 contains P_01
         # YUM 03 contains P_03
@@ -697,10 +694,10 @@ class TestCaseYumPackagesDownloading(TestCaseWithFlask):
         # - P_04 from YUM_04 - FAIL
         # - P_04 from YUM_03 - FAIL
         # - P_04 from YUM_04 - PASS
-        self.assertEquals(len(cbdata["failed_urls"]), 3)
-        self.assertEquals(cbdata["failed_urls"][0], url1+config.PACKAGE_03_01)
-        self.assertEquals(cbdata["failed_urls"][1], url1+config.PACKAGE_04_01)
-        self.assertEquals(cbdata["failed_urls"][2], url2+config.PACKAGE_04_01)
+        self.assertEqual(len(cbdata["failed_urls"]), 3)
+        self.assertEqual(cbdata["failed_urls"][0], url1+config.PACKAGE_03_01)
+        self.assertEqual(cbdata["failed_urls"][1], url1+config.PACKAGE_04_01)
+        self.assertEqual(cbdata["failed_urls"][2], url2+config.PACKAGE_04_01)
 
         # assert that all packages have been downloaded
         for pkg in pkgs:
@@ -792,8 +789,8 @@ class TestCaseYumPackagesDownloading(TestCaseWithFlask):
         #
         # You can use it to check adaptive mirror sorting behavior
         #
-        # E.g. from librepo checkout dir:
-        # LIBREPO_DEBUG_ADAPTIVEMIRRORSORTING="1" LIBREPO_DEBUG="1" PYTHONPATH=`readlink -f ./build/librepo/python/python2/` nosetests -s -v tests/python/tests/test_yum_package_downloading.py:TestCaseYumPackagesDownloading.test_download_packages_mirror_penalization_01
+        # E.g. from librepo checkout dir:        
+        # LIBREPO_DEBUG_ADAPTIVEMIRRORSORTING="1" LIBREPO_DEBUG="1" PYTHONPATH=`readlink -f ./build/librepo/python/` python3 -m unittest discover -s tests/python/ -p "test_yum_package_downloading.py" -k "test_download_packages_mirror_penalization_01"
 
         h = librepo.Handle()
 
